@@ -7,8 +7,8 @@ void meanElSym(double *b, int *a, int *first, int *last, int *item1, int* item2,
 void meanElSym0(double *b, int *a, int *first, int *last, int *item1, int* item2, int *nI, int *mS, double *g, int *idx);
 void ittot_mat0(double *b, int *a, double *c, int *first, int *last, int *nI, int *ms, double *pi);
 void ittot_mat(double *b, int *a, double *c, int *first, int *last, int *nI, int *ms, double *pi);
-void E_n(double *b, int *a, int *first, int *last, int *scoretab, int *nI, int *mS, double *expect);
 void E(double *b, int *a, int *first, int *last, int *scoretab, int *nI, int *mS, double *expect);
 void H(double *b, int *a, int* nPar, int *first, int *last, int *scoretab, int *nI, int *mS, double *Hess);
+void H0(double *b, int *a, int* nPar, int *first, int *last, int *nscore, int *nI, int *mS, double *Hess);
 
 #endif
